#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: views.py 11700 2019-09-05 08:49:19Z Lavender $
#
# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2019-09-05 17:49:19 +0900 (週四, 05 九月 2019) $
# $Revision: 11700 $
#
# Contributors:
#  Bear
#  Yachu

import base64

from django.db import models

class Token(models.Model):
    name = models.CharField(max_length=100)
    token = models.CharField(max_length=30, unique=True)
    username = models.CharField(max_length=255)
    password = models.CharField(max_length=255)
    description = models.TextField(null=True)
   
        